CountryStateCitySelection class
Immutable snapshot of the current country / state / city selection.
- Annotations
Constructors
- CountryStateCitySelection({Country? country, CountryState? state, City? city})
-
Creates a selection snapshot.
const
Properties
- city → City?
-
Selected city, or null when no city has been chosen for state.
final
- country → Country?
-
Selected country, or null when nothing is selected.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isComplete → bool
-
Whether all three levels are populated.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → CountryState?
-
Selected state, or null when no state has been chosen for country.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override